Learn R Programming

POMS (version 1.0.1)

subset_by_col_and_filt: Subset dataframe by column names and then post-filter

Description

Subset table by set of column names. After doing this, it will remove any rows and columns that are all 0's.

Usage

subset_by_col_and_filt(in_tab, col2keep, verbose = TRUE)

Value

dataframe with subset of specified columns (if they have at least one non-zero value), also with rows that only contain 0's removed.

Arguments

in_tab

input dataframe

col2keep

column names to retain in output (as long as they have at least one non-zero value).

verbose

flag to indicate that the final number of rows and columns (as well as the number removed) should be reported.