Subset table by set of column names. After doing this, it will remove any rows and columns that are all 0's.
subset_by_col_and_filt(in_tab, col2keep, verbose = TRUE)dataframe with subset of specified columns (if they have at least one non-zero value), also with rows that only contain 0's removed.
input dataframe
column names to retain in output (as long as they have at least one non-zero value).
flag to indicate that the final number of rows and columns (as well as the number removed) should be reported.